@@ -84,7 +84,7 @@
 #define KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED
-#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KNEWSTUFFCORE_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE KNEWSTUFFCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KNEWSTUFFCORE_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
