@@ -84,7 +84,7 @@
 #define KNEWSTUFFWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNEWSTUFFWIDGETS_NO_DEPRECATED
-#  define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
